.. _quantum-well:

quantum/well.py
===============

**Description**


Quantum potential well.

See :ref:`quantum-quantum_common`.


.. image:: /../doc/images/gallery/quantum-well.png


:download:`source code </../sfepy/examples/quantum/well.py>`

.. literalinclude:: /../sfepy/examples/quantum/well.py

